@@ -30,16 +30,6 @@ using namespace Rcpp;
 ////////////////////////////////////////////////////////////////////////////////
 // Auxiliary functions
 
-// Recursive depth-first GARP 
-// (used by DeepCpUp, defined in garp.cpp)
-std::vector<unsigned> RecGarp(unsigned cur_obs, std::vector<bool> *tabu, 
-                              unsigned *n_tabu, 
-                              std::vector<unsigned> *hist_tabu,
-                              std::vector<unsigned> ascendence, 
-                              std::vector<bool> strict_asc, 
-                              arma::mat *x, arma::mat *p, 
-                              double afriat_par);
-                         
 // boolean check GARP from an arma::mat argument 
 // (used by CpUp, defined in garp.cpp)
 bool ViolateGarp(arma::mat mat_px, double afriat_par);
@@ -380,114 +370,3 @@ RcppExport SEXP FastUp(SEXP px, SEXP samples, SEXP afriat) { try {
   // return to avoid CRAN warning:
   return wrap("ok");
 }
-
-
-////////////////////////////////////////////////////////////////////////////////
-// Depth-first Crawford-Pendakur upper bound
-// One run of depth-first search for each (obs, cluster) couple
-RcppExport SEXP DeepCpUp(SEXP x, SEXP p, SEXP samples, SEXP afriat) { try {
-  // import quantities and prices matrices (x, p)
-  NumericMatrix r_x(x), r_p(p);
-  unsigned n_obs= r_x.nrow();
-  arma::mat mat_x(r_x.begin(), r_x.nrow(), r_x.ncol());
-  arma::mat mat_p(r_p.begin(), r_p.nrow(), r_p.ncol());
-  double afriat_par= as<double>(afriat);
-  
-  // import samples matrix
-  NumericMatrix r_samp(samples);
-  arma::mat mat_samp(r_samp.begin(), r_samp.nrow(), r_samp.ncol()); 
-  unsigned n_tries= r_samp.ncol();
-  
-  // variables for main loop
-  arma::uvec clustering(n_obs); // clustering vector
-  arma::uvec clusterpop(n_obs); // cluster population vector
-  arma::uvec best_clustering(n_obs); // best clustering
-  arma::uvec best_clusterpop; // clusterpops (max n_clust=n_obs)
-  unsigned best_n_clust= 0; // best found number of clusters
-  NumericVector hist_n_clust(r_samp.ncol());
-
-  std::vector<bool> tabu(n_obs);
-  std::vector<unsigned> hist_tabu; // history of tabu obs (not reported)
-  hist_tabu.reserve(n_obs);
-  std::vector<unsigned> rec_garp;
-  arma::mat tmp_x, tmp_p;
-  unsigned n_tabu;
-  
-  arma::uvec crt_indices; // current indices
-  arma::uvec tmp_clusterpop;
-  arma::uvec cluster_order;
-  // loop on tries
-  for (unsigned i_try= 0; i_try < n_tries; i_try++) {
-    unsigned n_clust= 1;
-    clustering.zeros(); // zero = no cluster
-    clustering(mat_samp(0, i_try))= 1; // cluster of first sample is 1
-    clusterpop.zeros(); // reset clusterpops
-    clusterpop(0)= 1;
-    
-    // loop on observations
-    for (unsigned ind_samp= 1; ind_samp < n_obs; ind_samp++) {
-      bool b_violate_all= true;
-      unsigned i_obs= mat_samp(ind_samp, i_try); // index of current observation
-      
-      tmp_clusterpop= clusterpop.rows(0, n_clust - 1);
-      cluster_order= arma::stable_sort_index(tmp_clusterpop, 1); // descending
-      for (unsigned index_clust= 0; index_clust < n_clust; index_clust++) {
-        // take the "index_clust"th biggest cluster
-        unsigned i_clust= (unsigned)cluster_order(index_clust); 
-        
-        // find the indices of observations already included in the cluster
-        crt_indices= find(clustering == (i_clust + 1));
-        crt_indices.insert_rows(crt_indices.n_rows, 
-                                    arma::ones<arma::uvec>(1));
-        crt_indices(crt_indices.n_rows-1)= i_obs;
-        
-        // index of new obs in crt_pref
-        unsigned the_k= crt_indices.n_rows - 1; 
-        
-        // check for GARP violation
-        for (unsigned i_tabu=  0; i_tabu < tabu.size(); i_tabu++)
-          tabu[i_tabu]= false; // clear tabu list
-        hist_tabu.clear();
-        n_tabu= 0;
-        tmp_x= (arma::mat) mat_x.rows(crt_indices);
-        tmp_p= (arma::mat) mat_p.rows(crt_indices);
-        rec_garp= RecGarp(the_k, &tabu, &n_tabu, &hist_tabu,
-                          std::vector<unsigned>(0),
-                          std::vector<bool>(0),
-                          &tmp_x, &tmp_p, afriat_par);
-                          
-        // If no GARP violation, add to current cluster
-        if (rec_garp.size() == 0) { // No GARP violation
-          b_violate_all= false;
-          clustering(i_obs)= i_clust + 1;
-          clusterpop(i_clust)= clusterpop(i_clust) + 1;
-          break;
-        }
-      }
-      if (b_violate_all) {// if no fitting cluster found 
-        clusterpop(n_clust)= 1;
-        n_clust++;
-        clustering(i_obs)= n_clust;
-      }
-    }
-    
-    // check against current best run
-    if ( (i_try == 0) || (n_clust < best_n_clust) ) {
-      best_clustering= clustering;
-      best_clusterpop= clusterpop;
-      best_n_clust= n_clust;
-    }
-    hist_n_clust(i_try)= n_clust;
-  }
-  
-  return List::create(Named("clustering", wrap(best_clustering)),
-                      Named("cluster.pop", wrap(best_clusterpop)),
-                      Named("hist.n.types", hist_n_clust));
-} catch(std::exception &ex) {  
-  forward_exception_to_r(ex);
-} catch(...) { 
-  ::Rf_error("c++ exception (unknown reason)"); 
-}
-  // return to avoid CRAN warning:
-  return wrap("ok");
-}
